@@ -1,9 +1,11 @@
-from typing import Any, Dict, Optional, cast
+from json import dumps
+from typing import Any, Dict, Optional
 
 from .._config import Config
 from .._execution_context import ExecutionContext
 from .._folder_context import FolderContext
 from .._models import Action
+from .._utils import Endpoint
 from ._base_service import BaseService
 
 
@@ -19,14 +21,9 @@ class ActionsService(FolderContext, BaseService):
         app_id: str = "",
         app_version: int = -1,
     ) -> Action:
-        """
-        :param app_id: The `systemName` of the app.
-        :param app_version: The `deployVersion` of the app.
-        :param title: The title of the task.
-        """
+        endpoint = Endpoint("/orchestrator_/tasks/AppTasks/CreateAppTask")
 
-        endpoint = "/orchestrator_/tasks/AppTasks/CreateAppTask"
-        content = str(
+        content = dumps(
             {
                 "appId": app_id,
                 "appVersion": app_version,
@@ -35,15 +32,29 @@ class ActionsService(FolderContext, BaseService):
             }
         )
 
-        return cast(
-            Action,
-            self.request(
-                "POST",
-                endpoint,
-                content=content,
-            ).json(),
+        response = self.request(
+            "POST",
+            endpoint,
+            content=content,
         )
 
+        return Action.model_validate(response.json())
+
+    def retrieve(
+        self,
+        action_key: str,
+    ) -> Action:
+        endpoint = Endpoint("/orchestrator_/tasks/GenericTasks/GetTaskDataByKey")
+        params = {"taskKey": action_key}
+
+        response = self.request(
+            "GET",
+            endpoint,
+            params=params,
+        )
+
+        return Action.model_validate(response.json())
+
     @property
     def custom_headers(self) -> Dict[str, str]:
         return self.folder_headers
