@@ -1,4 +1,3 @@
-from logging import getLogger
 from os import environ as env
 from typing import Optional
 
@@ -6,8 +5,22 @@ from dotenv import load_dotenv
 
 from ._config import Config
 from ._execution_context import ExecutionContext
-from ._services import ActionsService, AssetsService, ProcessesService
+from ._services import (
+    ActionsService,
+    ApiClient,
+    AssetsService,
+    BucketsService,
+    ConnectionsService,
+    ContextGroundingService,
+    ProcessesService,
+    QueuesService,
+)
 from ._utils import setup_logging
+from ._utils.constants import (
+    ENV_BASE_URL,
+    ENV_UIPATH_ACCESS_TOKEN,
+    ENV_UNATTENDED_USER_ACCESS_TOKEN,
+)
 
 load_dotenv()
 
@@ -20,11 +33,11 @@ class UiPathSDK:
         secret: Optional[str] = None,
         debug: bool = False,
     ) -> None:
-        base_url_value = base_url or env.get("UIPATH_URL")
+        base_url_value = base_url or env.get(ENV_BASE_URL)
         secret_value = (
             secret
-            or env.get("UNATTENDED_USER_ACCESS_TOKEN")
-            or env.get("UIPATH_ACCESS_TOKEN")
+            or env.get(ENV_UNATTENDED_USER_ACCESS_TOKEN)
+            or env.get(ENV_UIPATH_ACCESS_TOKEN)
         )
 
         self._config = Config(
@@ -33,13 +46,12 @@ class UiPathSDK:
         )
 
         setup_logging(debug)
-        log = getLogger("uipath")
-
-        log.debug("CONFIG:")
-        log.debug(f"{self._config.model_dump()}\n")
-
         self._execution_context = ExecutionContext()
 
+    @property
+    def api_client(self) -> ApiClient:
+        return ApiClient(self._config, self._execution_context)
+
     @property
     def assets(self) -> AssetsService:
         return AssetsService(self._config, self._execution_context)
@@ -51,3 +63,19 @@ class UiPathSDK:
     @property
     def actions(self) -> ActionsService:
         return ActionsService(self._config, self._execution_context)
+
+    @property
+    def buckets(self) -> BucketsService:
+        return BucketsService(self._config, self._execution_context)
+
+    @property
+    def connections(self) -> ConnectionsService:
+        return ConnectionsService(self._config, self._execution_context)
+
+    @property
+    def context_grounding(self) -> ContextGroundingService:
+        return ContextGroundingService(self._config, self._execution_context)
+
+    @property
+    def queues(self) -> QueuesService:
+        return QueuesService(self._config, self._execution_context)
